Class: Pubid::Idf::SingleIdentifier

Inherits:
Identifier show all
Defined in:
lib/pubid/idf/single_identifier.rb

Overview

Base class for single IDF identifiers (base documents)

This class provides common attributes for all base document types like InternationalStandard and ReviewedMethod.

Supplement identifiers (amendments, corrigenda) should NOT inherit from this class - they should inherit directly from Identifier.

Note: The type attribute is inherited from the base Identifier class. Concrete classes should add their own default value like:

attribute :type, Components::Type, default: -> { self.class.type[:key] }

Constant Summary

Constants inherited from Identifier

Identifier::TYPE_KEY_TO_KLASS

Method Summary

Methods inherited from Identifier

create, #language_portion, #number_portion, parse, #publisher_portion, #to_s

Methods inherited from Pubid::Identifier

#base_identifier, #eql?, #exclude, #hash, #initialize, #mr_number, #mr_number_with_part, #mr_part, #mr_publisher, #mr_type, #mr_year, #new_edition_of?, polymorphic_name, #render, #resolve_urn_generator, #root, #to_mr_string, #to_s, #to_supplement_s, #to_urn, #urn_supplement_type, #urn_type_code, #year

Constructor Details

This class inherits a constructor from Pubid::Identifier