Class: Pubid::Iec::Components::VapSuffix
- Inherits:
-
Lutaml::Model::Serializable
- Object
- Lutaml::Model::Serializable
- Pubid::Iec::Components::VapSuffix
- Defined in:
- lib/pubid/iec/components/vap_suffix.rb
Overview
VAP (Validation Assessment Programme) suffix codes Single Responsibility: Represents VAP validation status suffixes
Constant Summary collapse
- CODES =
VAP suffix codes as defined by IEC
{ "CMV" => "Common Modifications and Variations", "RLV" => "Relevant", "SER" => "Serial", }.freeze
Instance Method Summary collapse
- #full_name ⇒ Object
-
#render_with_space ⇒ Object
VAP suffix appears after the main identifier with a space.
- #to_s ⇒ Object
- #validate! ⇒ Object
Instance Method Details
#full_name ⇒ Object
30 31 32 |
# File 'lib/pubid/iec/components/vap_suffix.rb', line 30 def full_name CODES[code] end |
#render_with_space ⇒ Object
VAP suffix appears after the main identifier with a space
35 36 37 |
# File 'lib/pubid/iec/components/vap_suffix.rb', line 35 def render_with_space " #{code}" end |
#to_s ⇒ Object
26 27 28 |
# File 'lib/pubid/iec/components/vap_suffix.rb', line 26 def to_s code end |