Class: Pubid::Ieee::Identifiers::DualPublished

Inherits:
Pubid::Ieee::Identifier show all
Defined in:
lib/pubid/ieee/identifiers/dual_published.rb

Overview

Dual Published Identifier Document jointly published by two organizations Example: "ANSI C37.61-1973 and IEEE Std 321-1973" This means the document was published together by both organizations

Instance Attribute Summary

Attributes inherited from Pubid::Ieee::Identifier

#code_obj, #draft_obj

Instance Method Summary collapse

Methods inherited from Pubid::Ieee::Identifier

additional_identifier_classes, #code, #draft, #draft_month, #exclude, from_hash, #initialize, #mr_number_with_part, #mr_publisher, #mr_type, #mr_year, parse, parse_single, #to_hash

Methods inherited from Pubid::Identifier

apply_mappings, #base, #base_document, concrete_class_for, #dated_version_of?, #draft_of?, #drop_supplements, #edition_of?, #eql?, #exclude, from_hash, #has_supplement?, #hash, #includes?, #initialize, #matches?, #mr_all_parts, #mr_edition, #mr_languages, #mr_number, #mr_number_with_part, #mr_part, #mr_publisher, #mr_subpart, #mr_supplement_suffix, #mr_type, #mr_year, #new_edition_of?, polymorphic_name, polymorphic_type_map, #related_to?, #render, #resolve_urn_generator, #root, #sibling_of?, #supplement_of?, #to_hash, #to_mr_string, #to_s, #to_slug, #to_supplement_s, #to_urn, #urn_supplement_type, #urn_type_code, #year

Constructor Details

This class inherits a constructor from Pubid::Ieee::Identifier

Instance Method Details

#publisherObject



17
18
19
20
# File 'lib/pubid/ieee/identifiers/dual_published.rb', line 17

def publisher
  # Return array of both publishers
  [first_identifier&.publisher, second_identifier&.publisher].compact
end