Class: Pubid::Nist::Identifiers::InteragencyReport
- Inherits:
-
Pubid::Nist::Identifier
- Object
- Lutaml::Model::Serializable
- Identifier
- Pubid::Nist::Identifier
- Pubid::Nist::Identifiers::InteragencyReport
- Defined in:
- lib/pubid/nist/identifiers/internal_report.rb
Overview
NIST Interagency Report (IR) / NISTIR Examples:
- "NIST IR 8115" = Interagency Report 8115
- "NIST IR 8115r1" = Interagency Report 8115 revision 1
- "NBS IR 73-197" = NBS Interagency Report 73-197
Constant Summary collapse
- TYPED_STAGES =
[ Pubid::Components::TypedStage.new( abbr: ["IR", "NIST IR", "NBS IR"], stage_code: "published", type_code: "ir", ), ].freeze
Constants inherited from Pubid::Nist::Identifier
Pubid::Nist::Identifier::COMPACT_DROP_ATTRS, Pubid::Nist::Identifier::COMPACT_FLAT_CODES, Pubid::Nist::Identifier::COMPACT_FLAT_VALUES, Pubid::Nist::Identifier::EQUALITY_IGNORED_ATTRS
Class Method Summary collapse
Instance Method Summary collapse
- #series_code ⇒ Object
-
#to_s(format = nil) ⇒ String
Override to_s to normalize MR input to short format by default But allow explicit format requests (e.g., format: :mr).
Methods inherited from Pubid::Nist::Identifier
#==, #append_mr_components, #append_short_components, #default_publisher, #edition_greater?, expand_code, expand_compact_hash, #extract_edition_number, from_hash, #hash, #initialize, #language, #matches?, #merge, parse, #publisher_abbreviated_name, #publisher_full_name, #render, #revision, #series_abbreviated_name, #series_full_name, #supplement_short, #to_abbreviated_style, #to_full_style, #to_hash, #to_mr_string, #to_mr_style, #to_short_style, #to_slug, #translation, #weight
Methods inherited from Identifier
apply_mappings, #base, #base_document, concrete_class_for, #dated_version_of?, #draft_of?, #drop_supplements, #edition_of?, #eql?, #exclude, from_hash, #has_supplement?, #hash, #includes?, #initialize, #matches?, #mr_all_parts, #mr_edition, #mr_languages, #mr_number, #mr_number_with_part, #mr_part, #mr_publisher, #mr_subpart, #mr_supplement_suffix, #mr_type, #mr_year, #new_edition_of?, polymorphic_name, polymorphic_type_map, #related_to?, #render, #resolve_urn_generator, #root, #sibling_of?, #supplement_of?, #to_hash, #to_mr_string, #to_slug, #to_supplement_s, #to_urn, #urn_supplement_type, #urn_type_code, #year
Constructor Details
This class inherits a constructor from Pubid::Nist::Identifier
Class Method Details
.type ⇒ Object
25 26 27 28 |
# File 'lib/pubid/nist/identifiers/internal_report.rb', line 25 def type { key: :ir, web: :interagency_report, title: "NIST Interagency Report", short: "IR" } end |
.typed_stages ⇒ Object
21 22 23 |
# File 'lib/pubid/nist/identifiers/internal_report.rb', line 21 def typed_stages TYPED_STAGES end |
Instance Method Details
#series_code ⇒ Object
31 32 33 |
# File 'lib/pubid/nist/identifiers/internal_report.rb', line 31 def series_code "IR" end |
#to_s(format = nil) ⇒ String
Override to_s to normalize MR input to short format by default But allow explicit format requests (e.g., format: :mr)
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/pubid/nist/identifiers/internal_report.rb', line 39 def to_s(format = nil) # Handle both keyword argument (hash) and positional argument (symbol/string) effective_format = if format.is_a?(Hash) format[:format] else format end # If explicit format is specified, use it. Otherwise, default to short. if effective_format.nil? super(:short) else super(effective_format) end end |