Class: Pubid::Nist::Identifiers::LetterCircular
- Defined in:
- lib/pubid/nist/identifiers/letter_circular.rb
Overview
NBS LC (Letter Circular) Examples:
- "NBS LC 378" - Basic letter circular
- "NBS LCIRC 378g" - With LCIRC variant, letter suffix
- "NBS LC 378G" - Letter suffix uppercase
- "NBS LC 378sup12/1926" - With supplement date
- "NBS LC 378r11/1925" - With revision date
- "NBS LC 378(sp)" - With language code
Constant Summary collapse
- TYPED_STAGES =
[ Pubid::Components::TypedStage.new( abbr: ["LCIRC"], # Single definition of truth stage_code: "published", type_code: "lc", ), ].freeze
Class Method Summary collapse
Instance Method Summary collapse
- #default_publisher ⇒ Object
-
#series_code ⇒ Object
series_code returns the normalized series name for rendering LCIRC normalizes to LC for standard rendering.
Class Method Details
.type ⇒ Object
28 29 30 31 |
# File 'lib/pubid/nist/identifiers/letter_circular.rb', line 28 def type { key: :lc, web: :letter_circular, title: "Letter Circular", short: "LCIRC" } end |
.typed_stages ⇒ Object
24 25 26 |
# File 'lib/pubid/nist/identifiers/letter_circular.rb', line 24 def typed_stages TYPED_STAGES end |
Instance Method Details
#default_publisher ⇒ Object
34 35 36 |
# File 'lib/pubid/nist/identifiers/letter_circular.rb', line 34 def default_publisher "NBS" end |
#series_code ⇒ Object
series_code returns the normalized series name for rendering LCIRC normalizes to LC for standard rendering
40 41 42 |
# File 'lib/pubid/nist/identifiers/letter_circular.rb', line 40 def series_code "LC" end |