Class: Pubid::Bsi::Identifiers::AerospaceStandard

Inherits:
SingleIdentifier show all
Defined in:
lib/pubid/bsi/identifiers/aerospace_standard.rb

Overview

AerospaceStandard handles BSI aerospace and specialized standards with letter prefixes indicating domain categorization.

Categorization includes:

  • Aircraft (A, B, C, F, G, HC, L, S, SP, X)

  • Methods related to aircraft (M)

  • Marine (MA)

  • Polyester (PL)

  • Aerospace materials (TA for Titanium-Aluminium alloys)

  • Automotive (AU)

  • Multi-letter prefixes (2A, 2B, 2C, 2F, 2G, 2HC, 2HR, 2L, 2M, 2S, 2SP, 2TA, 2X, etc.)

Examples:

BS A 109:2024       # Aircraft (A prefix)
BS AU 145e:2018     # Automotive (AU prefix) with letter suffix
BS M 38:1971        # Methods (M prefix)
BS 2A 293:2005      # Multi-letter prefix (2A)
BS SP 113:1954      # Specification (SP prefix)
BS TA 40:1971       # Titanium-Aluminium (TA prefix)

Constant Summary collapse

SINGLE_LETTER_PREFIXES =

Single-letter aerospace/specialized prefixes

%w[
  A B C F G L M S X
  AU HC MA PL QC SP TA
].freeze
MULTI_LETTER_PREFIXES =

Multi-letter prefixes (number + letter combination)

%w[
  2A 2B 2C 2F 2G 2HC 2HR 2L 2M 2S 2SP 2TA 2X
  3A 3B 3F 3G 3HR 3J 3L 3S 3TA
  4F 4L 4S
  5S 7S
].freeze
ALL_PREFIXES =
(SINGLE_LETTER_PREFIXES + MULTI_LETTER_PREFIXES).freeze
TYPED_STAGES =

TYPED_STAGES for aerospace standards (published by default)

[
  Pubid::Components::TypedStage.new(
    code: :pubas,
    stage_code: :published,
    type_code: :aerospace,
    abbr: ["BS"],
    name: "Aerospace/Specialized Standard",
    harmonized_stages: %w[60.00 60.60],
  ),
].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from SingleIdentifier

#<=>, #publisher

Methods included from Pubid::Bsi::Identifier

parse

Methods included from IdentifierFacade

#from_hash, #polymorphic_type_map

Methods inherited from Identifier

#base_identifier, #eql?, #exclude, #hash, #initialize, #mr_number, #mr_number_with_part, #mr_part, #mr_publisher, #mr_type, #mr_year, #new_edition_of?, polymorphic_name, #render, #resolve_urn_generator, #root, #to_mr_string, #to_supplement_s, #to_urn, #urn_supplement_type, #urn_type_code, #year

Constructor Details

This class inherits a constructor from Pubid::Identifier

Class Method Details

.typeObject



56
57
58
59
60
# File 'lib/pubid/bsi/identifiers/aerospace_standard.rb', line 56

def self.type
  { key: :aerospace,
    web: :aerospace_standard, title: "Aerospace/Specialized Standard",
    short: "BS" }
end

Instance Method Details

#to_s(lang: :en, lang_single: false) ⇒ Object



62
63
64
# File 'lib/pubid/bsi/identifiers/aerospace_standard.rb', line 62

def to_s(lang: :en, lang_single: false)
  render(format: :human, lang: lang, lang_single: lang_single)
end