Class: Pubid::Ieee::Identifiers::DualPublished
- Defined in:
- lib/pubid/ieee/identifiers/dual_published.rb
Overview
Dual Published Identifier Document jointly published by two organizations Example: "ANSI C37.61-1973 and IEEE Std 321-1973" This means the document was published together by both organizations
Instance Method Summary collapse
Instance Method Details
#publisher ⇒ Object
17 18 19 20 |
# File 'lib/pubid/ieee/identifiers/dual_published.rb', line 17 def publisher # Return array of both publishers [first_identifier&.publisher, second_identifier&.publisher].compact end |