Class: Pubid::Ieee::Identifiers::DualPublished
- Inherits:
-
Base
- Object
- Lutaml::Model::Serializable
- Pubid::Identifier
- Base
- Pubid::Ieee::Identifiers::DualPublished
- Defined in:
- lib/pubid/ieee/identifiers/dual_published.rb
Overview
Dual Published Identifier Document jointly published by two organizations Example: “ANSI C37.61-1973 and IEEE Std 321-1973” This means the document was published together by both organizations
Instance Attribute Summary
Attributes inherited from Base
Instance Method Summary collapse
Methods inherited from Base
#code, #draft, #draft_month, #initialize, parse, parse_single
Methods inherited from Pubid::Identifier
#base_identifier, #eql?, #exclude, #hash, #initialize, #mr_number, #mr_number_with_part, #mr_part, #mr_publisher, #mr_type, #mr_year, #new_edition_of?, polymorphic_name, #render, #resolve_urn_generator, #root, #to_mr_string, #to_supplement_s, #to_urn, #urn_supplement_type, #urn_type_code
Constructor Details
This class inherits a constructor from Pubid::Ieee::Identifiers::Base
Instance Method Details
#publisher ⇒ Object
21 22 23 24 |
# File 'lib/pubid/ieee/identifiers/dual_published.rb', line 21 def publisher # Return array of both publishers [first_identifier&.publisher, second_identifier&.publisher].compact end |
#to_s ⇒ Object
17 18 19 |
# File 'lib/pubid/ieee/identifiers/dual_published.rb', line 17 def to_s "#{first_identifier} and #{second_identifier}" end |