Class: Pubid::Nist::Identifiers::LetterCircular
- Inherits:
-
Base
- Object
- Lutaml::Model::Serializable
- Identifier
- Base
- Pubid::Nist::Identifiers::LetterCircular
- Defined in:
- lib/pubid/nist/identifiers/letter_circular.rb
Overview
NBS LC (Letter Circular) Examples:
-
“NBS LC 378” - Basic letter circular
-
“NBS LCIRC 378g” - With LCIRC variant, letter suffix
-
“NBS LC 378G” - Letter suffix uppercase
-
“NBS LC 378sup12/1926” - With supplement date
-
“NBS LC 378r11/1925” - With revision date
-
“NBS LC 378(sp)” - With language code
Constant Summary collapse
- TYPED_STAGES =
[ Pubid::Components::TypedStage.new( abbr: ["LCIRC"], # Single definition of truth stage_code: "published", type_code: "lc", ), ].freeze
Class Method Summary collapse
Instance Method Summary collapse
- #default_publisher ⇒ Object
-
#series_code ⇒ Object
series_code returns the normalized series name for rendering LCIRC normalizes to LC for standard rendering.
Methods inherited from Base
#edition_greater?, #extract_edition_number, #initialize, #language, #merge, #publisher, #revision, #to_s, #translation, #weight
Methods inherited from Identifier
#base_identifier, #eql?, #exclude, #hash, #initialize, #mr_number, #mr_number_with_part, #mr_part, #mr_publisher, #mr_type, #mr_year, #new_edition_of?, polymorphic_name, #render, #resolve_urn_generator, #root, #to_mr_string, #to_s, #to_supplement_s, #to_urn, #urn_supplement_type, #urn_type_code
Constructor Details
This class inherits a constructor from Pubid::Nist::Identifiers::Base
Class Method Details
.type ⇒ Object
28 29 30 |
# File 'lib/pubid/nist/identifiers/letter_circular.rb', line 28 def type { key: :lc, title: "Letter Circular", short: "LCIRC" } end |
.typed_stages ⇒ Object
24 25 26 |
# File 'lib/pubid/nist/identifiers/letter_circular.rb', line 24 def typed_stages TYPED_STAGES end |
Instance Method Details
#default_publisher ⇒ Object
33 34 35 |
# File 'lib/pubid/nist/identifiers/letter_circular.rb', line 33 def default_publisher "NBS" end |
#series_code ⇒ Object
series_code returns the normalized series name for rendering LCIRC normalizes to LC for standard rendering
39 40 41 |
# File 'lib/pubid/nist/identifiers/letter_circular.rb', line 39 def series_code "LC" end |